<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="az">
<context>
    <name>App.About</name>
    <message>
        <source>System Monitor</source>
        <translation>Sistem İzləyici</translation>
    </message>
    <message>
        <source>System Monitor is a tool to monitor realtime system load, view and control processes and services running on your system.</source>
        <translation>Sistem İzləyici, sistemin yüklənməsini, sisteminizdəki işlək proseslərə və xidmətlərə baxış və onlara nəzarəti izləmək üçün alətdir.</translation>
    </message>
</context>
<context>
    <name>BaseDetailViewWidget</name>
    <message>
        <source>Hide details</source>
        <translation>Təfərrüatları gizlətmək</translation>
    </message>
    <message>
        <source>Overall utilization</source>
        <translation>Ümumi istifadə</translation>
    </message>
    <message>
        <source>Individual utilization</source>
        <translation>Fərdi istifadə</translation>
    </message>
</context>
<context>
    <name>BlockDevItemWidget</name>
    <message>
        <source>Read</source>
        <translation>Oxumaq</translation>
    </message>
    <message>
        <source>Write</source>
        <translation>Yazmaq</translation>
    </message>
</context>
<context>
    <name>CPUDetailGrapTableItem</name>
    <message>
        <source>60 seconds</source>
        <translation>60 saniyə</translation>
    </message>
</context>
<context>
    <name>CPUInfoModel</name>
    <message>
        <source>%1 days %2 hours %3 minutes</source>
        <translation>%1 gün %2 saat %3 dəqiqə</translation>
    </message>
</context>
<context>
    <name>CPUSummaryTableModel</name>
    <message>
        <source>Utilization</source>
        <translation>İstifadə edilmə</translation>
    </message>
    <message>
        <source>Current frequency</source>
        <translation>Cari tezlik</translation>
    </message>
    <message>
        <source>Frequency</source>
        <translation>Tezlik</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>İstehsalçı</translation>
    </message>
    <message>
        <source>Sockets</source>
        <translation>Soketlər</translation>
    </message>
    <message>
        <source>Logical processors</source>
        <translation>Məntiqi proseslər</translation>
    </message>
    <message>
        <source>Virtualization</source>
        <translation>Virtuallaşdırma</translation>
    </message>
    <message>
        <source>L1i cache</source>
        <translation>L1i keş</translation>
    </message>
    <message>
        <source>L1d cache</source>
        <translation>L1d keş</translation>
    </message>
    <message>
        <source>L2 cache</source>
        <translation>L2 keş</translation>
    </message>
    <message>
        <source>L3 cache</source>
        <translation>L3 keş</translation>
    </message>
    <message>
        <source>Load average</source>
        <translation>Orta yüklənmə</translation>
    </message>
    <message>
        <source>File descriptors</source>
        <translation>Fayl təsvirçisi</translation>
    </message>
    <message>
        <source>Processes</source>
        <translation>Proseslər</translation>
    </message>
    <message>
        <source>Threads</source>
        <translation>Axınlar</translation>
    </message>
    <message>
        <source>Host name</source>
        <translation>Host adı</translation>
    </message>
    <message>
        <source>OS type</source>
        <translation>ƏS növü</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versiya</translation>
    </message>
    <message>
        <source>Up time</source>
        <translation>İşləmə müddəti</translation>
    </message>
</context>
<context>
    <name>ChartViewWidget</name>
    <message>
        <source>60 seconds</source>
        <translation>60 saniyə</translation>
    </message>
</context>
<context>
    <name>Common.Search</name>
    <message>
        <source>No search results</source>
        <translation>Axtarış nəticəsi yoxdur</translation>
    </message>
</context>
<context>
    <name>CompactCpuMonitor</name>
    <message>
        <source>Details</source>
        <translation>Təfərrüatlar</translation>
    </message>
</context>
<context>
    <name>CpuMonitor</name>
    <message>
        <source>Details</source>
        <translation>Təfərrüatlar</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Active.State</name>
    <message>
        <source>active</source>
        <translation>aktiv</translation>
    </message>
    <message>
        <source>reloading</source>
        <translation>yenidən yüklənir</translation>
    </message>
    <message>
        <source>inactive</source>
        <translation>Qeyri-aktiv</translation>
    </message>
    <message>
        <source>failed</source>
        <translation>alınmadı</translation>
    </message>
    <message>
        <source>activating</source>
        <translation>aktiv olunur</translation>
    </message>
    <message>
        <source>deactivating</source>
        <translation>söndürülür</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Load.State</name>
    <message>
        <source>stub</source>
        <translation>tıxac</translation>
    </message>
    <message>
        <source>not-found</source>
        <translation>tapılmadı</translation>
    </message>
    <message>
        <source>bad-setting</source>
        <translation>səhv-ayar</translation>
    </message>
    <message>
        <source>error</source>
        <translation>xəta</translation>
    </message>
    <message>
        <source>merged</source>
        <translation>birləşmiş</translation>
    </message>
    <message>
        <source>masked</source>
        <translation>maskalandı</translation>
    </message>
    <message>
        <source>loaded</source>
        <translation>yüklənmiş</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Startup.Mode</name>
    <message>
        <source>N/A</source>
        <translation>Ə/D</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Öz-özünə</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Əl ilə</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.State</name>
    <message>
        <source>enabled</source>
        <translation>qoşulmuş</translation>
    </message>
    <message>
        <source>disabled</source>
        <translation>söndürülmüş</translation>
    </message>
    <message>
        <source>static</source>
        <translation>sabit</translation>
    </message>
    <message>
        <source>transient</source>
        <translation>müvəqqəti</translation>
    </message>
    <message>
        <source>indirect</source>
        <translation>dolayı</translation>
    </message>
    <message>
        <source>enabled-runtime</source>
        <translation>aktiv-runtime</translation>
    </message>
    <message>
        <source>masked</source>
        <translation>maskalandı</translation>
    </message>
    <message>
        <source>generated</source>
        <translation>yaradıldı</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Sub.State</name>
    <message>
        <source>dead</source>
        <translation>məhv edilmiş</translation>
    </message>
    <message>
        <source>start-pre</source>
        <translation>öncə başlatmaq</translation>
    </message>
    <message>
        <source>start</source>
        <translation>başlamaq</translation>
    </message>
    <message>
        <source>start-post</source>
        <translation>start-post</translation>
    </message>
    <message>
        <source>running</source>
        <translation>işləyir</translation>
    </message>
    <message>
        <source>exited</source>
        <translation>çıxıldı</translation>
    </message>
    <message>
        <source>reload</source>
        <translation>yenidən yükləmək</translation>
    </message>
    <message>
        <source>stop</source>
        <translation>dayan</translation>
    </message>
    <message>
        <source>stop-watchdog</source>
        <translation>stop-watchdog</translation>
    </message>
    <message>
        <source>stop-sigterm</source>
        <translation>məhvetmə-siqnalı</translation>
    </message>
    <message>
        <source>stop-sigkill</source>
        <translation>dayan-siqnalı</translation>
    </message>
    <message>
        <source>stop-post</source>
        <translation>stop-post</translation>
    </message>
    <message>
        <source>final-sigterm</source>
        <translation>sonlandırma-siqnalı</translation>
    </message>
    <message>
        <source>final-sigkill</source>
        <translation>son-məhvetmə-siqnalı</translation>
    </message>
    <message>
        <source>failed</source>
        <translation>alınmadı</translation>
    </message>
    <message>
        <source>auto-restart</source>
        <translation>öz-özünə yenidən başlatmaq</translation>
    </message>
</context>
<context>
    <name>DeailTableModel</name>
    <message>
        <source>Used</source>
        <translation>İstifadə olunan</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Əlçatan</translation>
    </message>
    <message>
        <source>Shared</source>
        <translation>Paylaşılan</translation>
    </message>
    <message>
        <source>Cached</source>
        <translation>Keşlənmiş</translation>
    </message>
    <message>
        <source>Buffers</source>
        <translation>Buferlər</translation>
    </message>
    <message>
        <source>Cached swap</source>
        <translation>Keşlənmiş mübadilə bölməsi</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Aktiv</translation>
    </message>
    <message>
        <source>Inactive</source>
        <translation>Qeyri-aktiv</translation>
    </message>
    <message>
        <source>Dirty</source>
        <translation>Çirkli</translation>
    </message>
    <message>
        <source>Mapped</source>
        <translation>Xəritələndi</translation>
    </message>
    <message>
        <source>Total swap</source>
        <translation>Ümumi mübadilə bölməsi</translation>
    </message>
    <message>
        <source>Free swap</source>
        <translation>Boş mübadilə bölməsi</translation>
    </message>
    <message>
        <source>Slab</source>
        <translation>Hissə</translation>
    </message>
</context>
<context>
    <name>DeailTableModelBlock</name>
    <message>
        <source>Model</source>
        <translation>Model</translation>
    </message>
    <message>
        <source>Read speed</source>
        <translation>Oxuma sürəti</translation>
    </message>
    <message>
        <source>Write speed</source>
        <translation>Yazma sürəti</translation>
    </message>
    <message>
        <source>Capacity</source>
        <translation>Tutum</translation>
    </message>
    <message>
        <source>Sectors read</source>
        <translation>Oxunan sektorlar</translation>
    </message>
    <message>
        <source>Reads/s</source>
        <translation>Oxunur</translation>
    </message>
    <message>
        <source>Sectors read/s</source>
        <translation>Sektorlar oxunur</translation>
    </message>
    <message>
        <source>Reads merged/s</source>
        <translation>Birləşmiş oxunanlar</translation>
    </message>
    <message>
        <source>Sectors written</source>
        <translation>Yazılmış sektorlar</translation>
    </message>
    <message>
        <source>Writes completed </source>
        <translation>Yazılma başa çatdı</translation>
    </message>
    <message>
        <source>Writes merged</source>
        <translation>Birləşdirilmiş yazılar</translation>
    </message>
    <message>
        <source>Writes/s</source>
        <translation>Yazılır</translation>
    </message>
    <message>
        <source>Sectors written/s</source>
        <translation>Yazılmış sektorlar</translation>
    </message>
    <message>
        <source>Writes merged/s</source>
        <translation>Birləşdirilmiş yazılar</translation>
    </message>
</context>
<context>
    <name>Error.Dialog</name>
    <message>
        <source>OK</source>
        <comment>button</comment>
        <translation>OLDU</translation>
    </message>
</context>
<context>
    <name>Help.Shortcut.System</name>
    <message>
        <source>System</source>
        <translation>Sistem</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Qısayolları göstərmək</translation>
    </message>
</context>
<context>
    <name>Kill.Process.Dialog</name>
    <message>
        <source>Ending this process may cause data loss.
Are you sure you want to continue?</source>
        <translation>Bu prosesin sonlandırılması ilə verilənlər itirilə bilər.
Davam etmək istədiyinizə əminsiniz?</translation>
    </message>
    <message>
        <source>End process</source>
        <translation>Prosesin sonu</translation>
    </message>
    <message>
        <source>Force ending this process may cause data loss.
Are you sure you want to continue?</source>
        <translation>Bu prosesin məcburi sonlandırılması verilənlərin itirilməsi ilə nəticələnər.
Davam etmək istədiyinizə əminsiniz?</translation>
    </message>
    <message>
        <source>Force ending this application may cause data loss.
Are you sure you want to continue?</source>
        <translation>Bu tətbiqin məcburi sonlandırılması ilə verilənlər itirilə bilər.
Davam etmək istədiyinizə əminsiniz?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>İmtina</translation>
    </message>
    <message>
        <source>Force End</source>
        <comment>button</comment>
        <translation>Məcburi sonlandırmaq</translation>
    </message>
    <message>
        <source>End</source>
        <comment>button</comment>
        <translation>Sonlandırmaq</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Settings</source>
        <translation>Ayarlar</translation>
    </message>
</context>
<context>
    <name>MemStatViewWidget</name>
    <message>
        <source>Size</source>
        <translation>Ölçü</translation>
    </message>
</context>
<context>
    <name>NetInfoDetailItemDelegate</name>
    <message>
        <source>IP address:</source>
        <translation>İP ünvanı:</translation>
    </message>
    <message>
        <source>Netmask:</source>
        <translation>Şəbəkə maskası:</translation>
    </message>
    <message>
        <source>Broadcast:</source>
        <translation>Yayım:</translation>
    </message>
    <message>
        <source>Prefixlen:</source>
        <translation>Prefiksin uzun.:</translation>
    </message>
    <message>
        <source>Scope:</source>
        <translation>Sahəsi:</translation>
    </message>
</context>
<context>
    <name>NetInfoModel</name>
    <message>
        <source>Connection type</source>
        <translation>Bağlantı növü</translation>
    </message>
    <message>
        <source>ESSID</source>
        <translation>ESSID</translation>
    </message>
    <message>
        <source>Link quality</source>
        <translation>Bağlantı keyfiyyəti</translation>
    </message>
    <message>
        <source>Signal strength</source>
        <translation>Siqnal gücü</translation>
    </message>
    <message>
        <source>Noise level</source>
        <translation>Səs səviyyəsi</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>Bandwidth</source>
        <translation>Zolaq genişliyi</translation>
    </message>
    <message>
        <source>RX packets</source>
        <translation>Alınan paketlər</translation>
    </message>
    <message>
        <source>RX bytes</source>
        <translation>Alınan baytlar</translation>
    </message>
    <message>
        <source>RX errors</source>
        <translation>Alınma xətaları</translation>
    </message>
    <message>
        <source>RX dropped</source>
        <translation>Tullanılmış alınanlar</translation>
    </message>
    <message>
        <source>RX overruns</source>
        <translation>Alınanların daşması</translation>
    </message>
    <message>
        <source>RX frame</source>
        <translation>Alınma çərçivəsi</translation>
    </message>
    <message>
        <source>TX packets</source>
        <translation>Göndərilən paketlər</translation>
    </message>
    <message>
        <source>TX bytes</source>
        <translation>Alınan baytlar</translation>
    </message>
    <message>
        <source>TX errors</source>
        <translation>Göndərmə çərçivəsi</translation>
    </message>
    <message>
        <source>TX overruns</source>
        <translation>Göndərilənlərin daşması</translation>
    </message>
    <message>
        <source>TX carrier</source>
        <translation>Göndəriş daşıyıcısı</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>TX dropped</source>
        <translation>Tullanılmış alınanlar</translation>
    </message>
</context>
<context>
    <name>Process.Attributes.Dialog</name>
    <message>
        <source>Command line</source>
        <translation>Əmr sətri</translation>
    </message>
    <message>
        <source>Start time</source>
        <translation>Başlama vaxtı</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Adı</translation>
    </message>
</context>
<context>
    <name>Process.Choose.Window.Dialog</name>
    <message>
        <source>Click the application you want to end</source>
        <translation>Sonlandırmaq istədiyiniz tətbiqi seçin</translation>
    </message>
</context>
<context>
    <name>Process.Graph.Title</name>
    <message>
        <source>Memory</source>
        <translation>Yddaş</translation>
    </message>
    <message>
        <source>Receive</source>
        <translation>Almaq</translation>
    </message>
</context>
<context>
    <name>Process.Graph.View</name>
    <message>
        <source>CPU</source>
        <translation>MP</translation>
    </message>
    <message>
        <source>Disk read</source>
        <translation>Diskin oxunması</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>Diskin yazılması</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Yddaş</translation>
    </message>
    <message>
        <source>Swap</source>
        <translation>Mübadilə bölməsi</translation>
    </message>
    <message>
        <source>Not enabled</source>
        <translation>Qoşulmayıb</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Yükləmək</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Göndərmək</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Şəbəkə</translation>
    </message>
    <message>
        <source>Total Received</source>
        <translation>Ümumi alınan</translation>
    </message>
    <message>
        <source>Total Sent</source>
        <translation>Ümumi göndərilən</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Göndərmək</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>Disklər</translation>
    </message>
</context>
<context>
    <name>Process.Priority</name>
    <message>
        <source>Very high</source>
        <translation>Çox yüksək</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Yüksək</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Aşağı</translation>
    </message>
    <message>
        <source>Very low</source>
        <translation>Çox aşağı</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>Xüsusi</translation>
    </message>
    <message>
        <source>Invalid</source>
        <translation>Yararsız</translation>
    </message>
    <message>
        <source>PID: %1, Error: [%2] %3</source>
        <translation>PID: %1, Xəta: [%2] %3</translation>
    </message>
    <message>
        <source>Failed to change process priority</source>
        <translation>Prosesin üstünlüyünü dəyişmək alınmadı</translation>
    </message>
</context>
<context>
    <name>Process.Show.Mode</name>
    <message>
        <source>Applications</source>
        <translation>Tətbiqlər</translation>
    </message>
    <message>
        <source>My processes</source>
        <translation>Mənim proseslərim</translation>
    </message>
    <message>
        <source>All processes</source>
        <translation>Bütün proseslər</translation>
    </message>
</context>
<context>
    <name>Process.Loading</name>
    <message>
        <source>Loading</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Process.Signal</name>
    <message>
        <source>Failed to pause process</source>
        <translation>Prosesə fasilə vermək alınmadı</translation>
    </message>
    <message>
        <source>Failed to resume process</source>
        <translation>Prosesi davam etdirmək alınmadı</translation>
    </message>
    <message>
        <source>Failed to kill process</source>
        <translation>Prosesi məhv etmək alınmadı</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Bilinməyən xəta</translation>
    </message>
    <message>
        <source>Failed in sending signal to process</source>
        <translation>Prosesə siqnal göndərilə bilmədi</translation>
    </message>
    <message>
        <source>Failed to end process</source>
        <translation>Prosesi sonlandırmaq baş tutmadı</translation>
    </message>
</context>
<context>
    <name>Process.Summary</name>
    <message>
        <source>(%1 applications and %2 processes are running)</source>
        <translation>(%1 tətbiq və %2 proses işləyir)</translation>
    </message>
</context>
<context>
    <name>Process.Table</name>
    <message>
        <source>No response</source>
        <translation>Cavab yoxdur</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Dayandırmaq</translation>
    </message>
    <message>
        <source>Tray</source>
        <translation>Panel</translation>
    </message>
</context>
<context>
    <name>Process.Table.Context.Menu</name>
    <message>
        <source>View command location</source>
        <translation>Əmrin yerinə baxmaq</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Xüsusiyyətlər</translation>
    </message>
    <message>
        <source>End process</source>
        <translation>Prosesin sonu</translation>
    </message>
    <message>
        <source>Resume process</source>
        <translation>Prosesə davam</translation>
    </message>
    <message>
        <source>Kill process</source>
        <translation>Prosesi məh etmək</translation>
    </message>
    <message>
        <source>Change priority</source>
        <translation>Üstünlüyü dəyişmək</translation>
    </message>
    <message>
        <source>Suspend process</source>
        <translation>Prosesi dayandırmaq</translation>
    </message>
</context>
<context>
    <name>Process.Table.Custom.Priority.Dialog</name>
    <message>
        <source>Custom Priority</source>
        <translation>Xüsusi üstünlük</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>İmtina</translation>
    </message>
    <message>
        <source>Change</source>
        <comment>button</comment>
        <translation>Dəyişmək</translation>
    </message>
</context>
<context>
    <name>Process.Table.Header</name>
    <message>
        <source>Name</source>
        <translation>Adı</translation>
    </message>
    <message>
        <source>CPU</source>
        <translation>MP</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Yaddaş</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>Diskin yazılması</translation>
    </message>
    <message>
        <source>Disk read</source>
        <translation>Diskin oxunması</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Yükləmək</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Göndərmək</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>User</source>
        <translation>İstifadəçi</translation>
    </message>
    <message>
        <source>Nice</source>
        <translation>Yaxşı</translation>
    </message>
    <message>
        <source>Priority</source>
        <translation>Üstünlük</translation>
    </message>
    <message>
        <source>Shared memory</source>
        <translation>Paylaşılan yaddaş</translation>
    </message>
    <message>
        <source>Virtual memory</source>
        <translation>Virtual yaddaş</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Not support</source>
        <translation>Dəstəklənmir</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ayarlar</translation>
    </message>
    <message>
        <source>System Protection</source>
        <translation>Sistemin qorunması</translation>
    </message>
    <message>
        <source>Show warnings when the usage exceeds the thresholds</source>
        <translation>İstifadə, göstərilən həddi aşdıqda xəbərdarlıqları göstərmək</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>Bildirişlər</translation>
    </message>
    <message>
        <source>CPU warning threshold (%)</source>
        <translation>MP (CPU) xəbərdarlığı həddi (%)</translation>
    </message>
    <message>
        <source>Memory warning threshold (%)</source>
        <translation>Yaddaşın xəbərdarlıq həddi (%)</translation>
    </message>
    <message>
        <source>Warning interval (min)</source>
        <translation>Xəbərdarlıq aralığı (dəq)</translation>
    </message>
</context>
<context>
    <name>Service.Action.Set.Startup.Mode</name>
    <message>
        <source>Failed to set service startup type</source>
        <translation>Xidmətin başladılma növünü təyin etmək baş tutmadı</translation>
    </message>
    <message>
        <source>Error: Failed to set service startup type due to the crashed sub process.</source>
        <translation>Xəta: Ona tabe olan proses çökdüyü halda, xidmətin başladılma növü dəyişdirilə bilmədi.</translation>
    </message>
</context>
<context>
    <name>Service.Instance.Name.Dialog</name>
    <message>
        <source>Service instance name</source>
        <translation>Xidmətin adı</translation>
    </message>
    <message>
        <source>OK</source>
        <comment>button</comment>
        <translation>OLDU</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>İmtina</translation>
    </message>
</context>
<context>
    <name>Service.Table.Context.Menu</name>
    <message>
        <source>Refresh</source>
        <translation>Təzələmək</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Başlamaq</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Dayandırmaq</translation>
    </message>
    <message>
        <source>Restart</source>
        <translation>Yenidən başlatmaq</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Öz-özünə</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Əl ilə</translation>
    </message>
    <message>
        <source>Startup type</source>
        <translation>Başladılma növü</translation>
    </message>
</context>
<context>
    <name>Service.Table.Header</name>
    <message>
        <source>Name</source>
        <translation>Adı</translation>
    </message>
    <message>
        <source>Load</source>
        <translation>Yükləmək</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Aktiv</translation>
    </message>
    <message>
        <source>Sub</source>
        <translation>Tabe olan</translation>
    </message>
    <message>
        <source>State</source>
        <translation>Vəziyyət</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Təsviri</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Startup Type</source>
        <translation>Başladılma növü</translation>
    </message>
</context>
<context>
    <name>SystemProtectionSetting</name>
    <message>
        <source>Settings</source>
        <translation>Ayarlar</translation>
    </message>
    <message>
        <source>(Modifiable)</source>
        <translation>(Dəyişdiriləbilən)</translation>
    </message>
    <message>
        <source>Range: %1-%2</source>
        <translation>Aralıq: %1-%2: </translation>
    </message>
</context>
<context>
    <name>Title.Bar.Context.Menu</name>
    <message>
        <source>Force end application</source>
        <translation>Tətbiqi məcburi sonlandırmaq</translation>
    </message>
    <message>
        <source>Expand</source>
        <translation>Genişləndirmək</translation>
    </message>
    <message>
        <source>Compact</source>
        <translation>Yığcam</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Görünüş</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Search</name>
    <message>
        <source>Search</source>
        <translation>Axtarış</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Switch</name>
    <message>
        <source>Processes</source>
        <translation>Proseslər</translation>
    </message>
    <message>
        <source>Services</source>
        <translation>Xidmətlər</translation>
    </message>
</context>
</TS>
